pub trait ScanFromStr {
// Required method
fn scan_from_str(&mut self, s: &str) -> Result<(), ScanError>;
}Expand description
Minimal trait to write a string token into a value.
pub trait ScanFromStr {
// Required method
fn scan_from_str(&mut self, s: &str) -> Result<(), ScanError>;
}Minimal trait to write a string token into a value.